==> better-admin-ui-vue-0.0.33.tgz: package/es/components/FileUpload/FileUpload.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

/**
 * @Date: 2020/11/24 10:20 上午
 * @Author: Fioanna
 * @Description: 图片上传
 */
import axios from 'axios';
import md5 from 'js-md5';
import AUpload from 'ant-design-vue/es/upload';
import AIcon from 'ant-design-vue/es/icon';
import AModal from 'ant-design-vue/es/modal';
import fileUploadProps from './types';
import './style.less'; // import { previewImage } from 'ant-design-vue/es/upload/utils'
// 文件名后缀列表

var FILE_SUFFIX_LIST = ['png', 'jpg', 'jpeg'];
var FILE_TYPE_SUFFIX_MAP = {
  'image/png': 'png',
  'image/jpeg': 'jpg'
};
export default {
  name: 'EFileUpload',
  props: fileUploadProps,
  data: function data() {
    return {
      fileList: [],
      // 已经上传的文件列表（受控）
      previewVisible: false,
      // 预览模态是否显示
      previewImage: '',
      // 当前预览的图片
      loading: false,
      // 当前上传是否进行中，如果是进行中则会展示loading的icon
      disabled: true,
      // 是否禁用
      fileUrlList: undefined // change事件传出的value

    };
  },
  watch: {
    fileList: function fileList(newVal) {
      var fileKey = this.$props.needSignature ? 'fileFolder' : 'url';

      if (this.maxCount > 1) {
        // 超出一个数据就返回列表
        this.$data.fileUrlList = newVal.map(function (item) {
          return item[fileKey];
        });
      } else {
        // 否则仅返回一张图
        if (newVal.length > 0) {
          this.$data.fileUrlList = newVal[0][fileKey];
        } else {
          this.$data.fileUrlList = undefined;
        }
      }

      this.$emit('input', this.$data.fileUrlList);
      this.$emit('change', this.$data.fileUrlList);
    },
    ossClient: function ossClient(newVal) {
      if (newVal) {
        this.$data.disabled = false;

        this._handleExistedFileList();
      }
    },
    value: function value(newVal, oldVal) {
      var newValStr = JSON.stringify(newVal);
      var oldValStr = JSON.stringify(oldVal);

      if (Object.keys(this.ossClient).length > 0 && newValStr !== oldValStr && newVal !== this.$data.fileUrlList) {
        this.$data.disabled = false;

        this._handleExistedFileList();
      }
    }
  },
  computed: {
    desc: function desc() {
      return this.$data.disabled ? '初始化中...' : this.$props.description;
    },
    action: function action() {
      var actionHeader = this.ossClient.secure ? 'https' : 'http';
      return "".concat(actionHeader, "://").concat(this.ossClient.bucket, ".").concat(this.ossClient.endPoint);
    }
  },
  inject: ['resetOssClient'],
  created: function created() {
    this._init();
  },
  methods: {
    /**
     * 初始化
     * @private
     */
    _init: function _init() {
      if (this.ossClient && Object.keys(this.ossClient).length > 0) {
        this.$data.disabled = false;

        this._handleExistedFileList();
      } else {
        this._resetOssClient();
      }
    },

    /**
     * 重新初始化oss对象
     * @private
     */
    _resetOssClient: function _resetOssClient() {
      if (this.resetOssClient) {
        this.resetOssClient();
      } else {
        console.error('Can Not dispatch inject method "resetOssClient",Please Provide this in your project！');
      }
    },

    /**
     * 处理预设的图片
     */
    _handleExistedFileList: function _handleExistedFileList() {
      var _this = this;

      if (this.value) {
        var newFileList = []; // 根据value的类型来做处理

        var valueArr = this.value;

        if (typeof this.value === 'string') {
          valueArr = [this.value];
        }

        valueArr.forEach(function (name, index) {
          var targetUrl = _this.$props.needSignature ? _this.ossClient.signatureUrl(name) : name;
          newFileList.push({
            uid: new Date().getTime() + index,
            status: 'done',
            name: name,
            url: targetUrl,
            thumbUrl: targetUrl,
            fileFolder: _this.$props.needSignature ? name : undefined
          });
        });
        this.fileList = newFileList;
      } else {
        if (this.fileList.length > 0) {
          // 如果图片列表有数据则清空
          this.fileList = [];
        }
      }
    },

    /**
     * 处理预览回调
     * @param file 当前点击预览的文件对象
     * @private
     */
    _handlePreview: function _handlePreview(file) {
      this.previewImage = file.thumbUrl;
      this.previewVisible = true;
    },

    /**
     * 处理业务变更
     * @param fileList 已经上传的文件列表
     * @private
     */
    _handleChange: function _handleChange(_ref) {
      var file = _ref.file;

      if (file.status === 'removed') {
        var index = this.fileList.findIndex(function (item) {
          return item.uid === file.uid;
        });

        if (index !== -1) {
          this.fileList.splice(index, 1);
        }
      }
    },

    /**
     * 取消预览
     * @private
     */
    _handleCancelPreview: function _handleCancelPreview() {
      this.previewVisible = false;
    },

    /**
     * 上传前的处理函数，处理支持的文件类型及大小
     * @param file
     * @returns {Promise<unknown>|boolean}
     * @private
     */
    _handleBeforeUpload: function _handleBeforeUpload(file) {
      var _this2 = this;

      var isJpgOrPng = file.type === 'image/jpeg' || file.type === 'image/png';

      if (!isJpgOrPng) {
        this.$message.error('只允许jpeg、png格式图片');
        return false;
      }

      var isLtSize = file.size < this.$props.maxStoreSize * 1024 * 1024;

      if (!isLtSize) {
        this.$message.error("\u56FE\u7247\u5927\u5C0F\u4E0D\u80FD\u8D85\u8FC7".concat(this.$props.maxStoreSize, "M"));
        return false;
      }

      if (this.$props.needSquare) {
        return new Promise(function (resolve, reject) {
          var reader = new FileReader();
          reader.readAsDataURL(file);

          reader.onload = function () {
            // 让页面中的img标签的src指向读取的路径
            var img = new Image();
            img.src = reader.result;

            if (img.complete) {
              // 如果存在浏览器缓存中
              _this2._getIsSquare(img, resolve, reject);
            } else {
              img.onload = function () {
                _this2._getIsSquare(img, resolve, reject);
              };
            }
          };
        });
      } // return isJpgOrPng && isLtSize
      // return true


      return false;
    },

    /**
     * 判断是否是正方形的图
     * @param img
     * @param resolve
     * @param reject
     * @private
     */
    _getIsSquare: function _getIsSquare(img, resolve, reject) {
      var isSquare = img.width === img.height;

      if (!isSquare) {
        this.$message.error(this.$props.squareMsg);
        reject(new Error(this.$props.squareMsg));
      } else {
        resolve();
      }
    },

    /**
     * 自定义处理上传逻辑函数
     * @param file
     * @private
     */
    _handleCustomRequest: function () {
      var _handleCustomRequest2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(file) {
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.prev = 0;
                // console.log('~~~_handleCustomRequest~~~', file)
                this.loading = true;

                if (!this.$props.needSignature) {
                  _context.next = 7;
                  break;
                }

                _context.next = 5;
                return this._uploadBySignature(file.file);

              case 5:
                _context.next = 9;
                break;

              case 7:
                _context.next = 9;
                return this._upload(file.file);

              case 9:
                _context.next = 13;
                break;

              case 11:
                _context.prev = 11;
                _context.t0 = _context["catch"](0);

              case 13:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, this, [[0, 11]]);
      }));

      function _handleCustomRequest(_x) {
        return _handleCustomRequest2.apply(this, arguments);
      }

      return _handleCustomRequest;
    }(),

    /**
     * 普通上传上传
     * @param file
     * @private
     */
    _upload: function () {
      var _upload2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(file) {
        var fileSuffix, formData, data, key, instance, targetUrl;
        return _regeneratorRuntime.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                _context2.prev = 0;
                // 获取文件后缀名
                fileSuffix = this._getFileSuffix(file);
                formData = _extends({}, this.ossClient, {
                  name: file.name,
                  key: this.ossClient.dir + '/' + new Date().getTime() + '.' + fileSuffix
                });
                delete formData.dir;
                delete formData.endPoint;
                delete formData.bucket;
                data = new FormData();

                for (key in formData) {
                  data.append(key, formData[key]);
                }

                data.append('file', file);
                instance = axios.create();
                instance.defaults.headers = {
                  'Content-Type': 'multipart/form-data'
                };
                instance.defaults.baseURL = this.action;
                _context2.next = 14;
                return instance.request({
                  method: 'post',
                  data: data
                });

              case 14:
                targetUrl = "".concat(this.action, "/").concat(formData.key);

                this._uploadSuccess(file.name, targetUrl);

                _context2.next = 21;
                break;

              case 18:
                _context2.prev = 18;
                _context2.t0 = _context2["catch"](0);

                // 加密上传的事直接error.response.status
                this._uploadError(_context2.t0.response || _context2.t0);

              case 21:
              case "end":
                return _context2.stop();
            }
          }
        }, _callee2, this, [[0, 18]]);
      }));

      function _upload(_x2) {
        return _upload2.apply(this, arguments);
      }

      return _upload;
    }(),

    /**
     * 加密上传上传
     * @param file
     * @private
     */
    _uploadBySignature: function () {
      var _uploadBySignature2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3(file) {
        var fileName, fileSuffix, md5FileName, url, result, targetUrl;
        return _regeneratorRuntime.wrap(function _callee3$(_context3) {
          while (1) {
            switch (_context3.prev = _context3.next) {
              case 0:
                _context3.prev = 0;
                fileName = file.name; // 获取文件后缀名

                fileSuffix = this._getFileSuffix(file);
                md5FileName = md5(file.uid + '_' + fileName);
                url = "".concat(this.ossClient.fileFolder).concat(md5FileName, ".").concat(fileSuffix);
                _context3.next = 7;
                return this.ossClient.put(url, file);

              case 7:
                result = _context3.sent;
                targetUrl = this.ossClient.signatureUrl(result.name);

                this._uploadSuccess(fileName, targetUrl, result.name);

                _context3.next = 15;
                break;

              case 12:
                _context3.prev = 12;
                _context3.t0 = _context3["catch"](0);

                // 加密上传的事直接error.status
                this._uploadError(_context3.t0);

              case 15:
              case "end":
                return _context3.stop();
            }
          }
        }, _callee3, this, [[0, 12]]);
      }));

      function _uploadBySignature(_x3) {
        return _uploadBySignature2.apply(this, arguments);
      }

      return _uploadBySignature;
    }(),

    /**
     * 获取文件后缀
     * @param file
     * @returns {string|any}
     * @private
     */
    _getFileSuffix: function _getFileSuffix(file) {
      var name = file.name,
          type = file.type; // 获取文件后缀名获取后缀

      var fileSuffix = name.substring(name.lastIndexOf('.') + 1);

      if (FILE_SUFFIX_LIST.includes(fileSuffix)) {
        return fileSuffix;
      } // 根据文件类型来获取后缀


      fileSuffix = FILE_TYPE_SUFFIX_MAP[type];

      if (FILE_SUFFIX_LIST.includes(fileSuffix)) {
        return fileSuffix;
      } // 没有符合的默认使用png


      return 'png';
    },

    /**
     * 加密上传成功后处理
     * @param name
     * @param targetUrl
     * @param fileFolder 图片文件夹，加密上传有此参数
     * @private
     */
    _uploadSuccess: function _uploadSuccess(name, targetUrl, fileFolder) {
      this._addFileToFileList(name, targetUrl, fileFolder);

      this.$message.success('上传成功');
      this.loading = false;
    },

    /**
     * 上传失败后处理
     * @param error
     * @private
     */
    _uploadError: function _uploadError(error) {
      var status = error.status;
      this.loading = false;

      if (status === 403 || status === '403') {
        // 这里要考虑是不是真的是这样取错误码的
        this.$message.error('上传失败，请重试');

        this._resetOssClient();
      } else {
        this.$message.error('上传失败' + status);
      }
    },

    /**
     * 往文件列表里面添加文件
     * @param name 图片名称
     * @param targetUrl 图片url
     * @param fileFolder 图片文件夹，加密上传有此参数
     * @private
     */
    _addFileToFileList: function _addFileToFileList(name, targetUrl, fileFolder) {
      var fileItem = {
        uid: new Date().getTime(),
        status: 'done',
        name: name,
        url: targetUrl,
        // 缩略图
        thumbUrl: targetUrl,
        fileFolder: fileFolder
      };

      if (this.$props.maxCount === 1 && this.$props.listType === 'text') {
        this.fileList = [fileItem];
      } else {
        this.fileList.push(fileItem);
      }
    }
  },
  render: function render() {
    var h = arguments[0];
    var _this$$data = this.$data,
        fileList = _this$$data.fileList,
        disabled = _this$$data.disabled,
        loading = _this$$data.loading,
        previewVisible = _this$$data.previewVisible,
        previewImage = _this$$data.previewImage;
    var _this$$props = this.$props,
        maxCount = _this$$props.maxCount,
        listType = _this$$props.listType;
    return h("div", [h(AUpload, {
      attrs: {
        listType: listType,
        fileList: fileList,
        disabled: disabled,
        beforeUpload: this._handleBeforeUpload,
        customRequest: this._handleCustomRequest
      },
      on: {
        "preview": this._handlePreview,
        "change": this._handleChange
      }
    }, [fileList.length < maxCount ? h("div", [h(AIcon, {
      attrs: {
        type: loading ? 'loading' : 'plus'
      }
    }), h("div", {
      attrs: {
        className: "ant-upload-text"
      }
    }, [this.desc])]) : null]), h(AModal, {
      attrs: {
        visible: previewVisible,
        footer: null
      },
      on: {
        "cancel": this._handleCancelPreview
      }
    }, [h("img", {
      attrs: {
        alt: "example",
        src: previewImage
      },
      style: "width: 100%"
    })])]);
  }
};

==> better-admin-ui-vue-0.0.34.tgz: package/es/components/FileUpload/FileUpload.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

/**
 * @Date: 2020/11/24 10:20 上午
 * @Author: Fioanna
 * @Description: 图片上传
 */
import axios from 'axios';
import md5 from 'js-md5';
import AUpload from 'ant-design-vue/es/upload';
import AIcon from 'ant-design-vue/es/icon';
import AModal from 'ant-design-vue/es/modal';
import fileUploadProps from './types';
import './style.less'; // import { previewImage } from 'ant-design-vue/es/upload/utils'
// 文件名后缀列表

var FILE_SUFFIX_LIST = ['png', 'jpg', 'jpeg'];
var FILE_TYPE_SUFFIX_MAP = {
  'image/png': 'png',
  'image/jpeg': 'jpg'
};
export default {
  name: 'EFileUpload',
  props: fileUploadProps,
  data: function data() {
    return {
      fileList: [],
      // 已经上传的文件列表（受控）
      previewVisible: false,
      // 预览模态是否显示
      previewImage: '',
      // 当前预览的图片
      loading: false,
      // 当前上传是否进行中，如果是进行中则会展示loading的icon
      disabled: true,
      // 是否禁用
      fileUrlList: undefined // change事件传出的value

    };
  },
  watch: {
    fileList: function fileList(newVal) {
      var fileKey = this.$props.needSignature ? 'fileFolder' : 'url';

      if (this.maxCount > 1) {
        // 超出一个数据就返回列表
        this.$data.fileUrlList = newVal.map(function (item) {
          return item[fileKey];
        });
      } else {
        // 否则仅返回一张图
        if (newVal.length > 0) {
          this.$data.fileUrlList = newVal[0][fileKey];
        } else {
          this.$data.fileUrlList = undefined;
        }
      }

      this.$emit('input', this.$data.fileUrlList);
      this.$emit('change', this.$data.fileUrlList);
    },
    ossClient: function ossClient(newVal) {
      if (newVal) {
        this.$data.disabled = false;

        this._handleExistedFileList();
      }
    },
    value: function value(newVal, oldVal) {
      var newValStr = JSON.stringify(newVal);
      var oldValStr = JSON.stringify(oldVal);

      if (Object.keys(this.ossClient).length > 0 && newValStr !== oldValStr && newVal !== this.$data.fileUrlList) {
        this.$data.disabled = false;

        this._handleExistedFileList();
      }
    }
  },
  computed: {
    desc: function desc() {
      return this.$data.disabled ? '初始化中...' : this.$props.description;
    },
    action: function action() {
      var actionHeader = this.ossClient.secure ? 'https' : 'http';
      return "".concat(actionHeader, "://").concat(this.ossClient.bucket, ".").concat(this.ossClient.endPoint);
    }
  },
  inject: ['resetOssClient'],
  created: function created() {
    this._initFileList();
  },
  methods: {
    /**
     * 初始化
     * @private
     */
    _initFileList: function _initFileList() {
      if (this.ossClient && Object.keys(this.ossClient).length > 0) {
        this.$data.disabled = false;

        this._handleExistedFileList();
      } else {
        this._resetOssClient();
      }
    },

    /**
     * 重新初始化oss对象
     * @private
     */
    _resetOssClient: function _resetOssClient() {
      if (this.resetOssClient) {
        this.resetOssClient();
      } else {
        console.error('Can Not dispatch inject method "resetOssClient",Please Provide this in your project！');
      }
    },

    /**
     * 处理预设的图片
     */
    _handleExistedFileList: function _handleExistedFileList() {
      var _this = this;

      if (this.value) {
        var newFileList = []; // 根据value的类型来做处理

        var valueArr = this.value;

        if (typeof this.value === 'string') {
          valueArr = [this.value];
        }

        valueArr.forEach(function (name, index) {
          var targetUrl = _this.$props.needSignature ? _this.ossClient.signatureUrl(name) : name;
          newFileList.push({
            uid: new Date().getTime() + index,
            status: 'done',
            name: name,
            url: targetUrl,
            thumbUrl: targetUrl,
            fileFolder: _this.$props.needSignature ? name : undefined
          });
        });
        this.fileList = newFileList;
      } else {
        if (this.fileList.length > 0) {
          // 如果图片列表有数据则清空
          this.fileList = [];
        }
      }
    },

    /**
     * 处理预览回调
     * @param file 当前点击预览的文件对象
     * @private
     */
    _handlePreview: function _handlePreview(file) {
      this.previewImage = file.thumbUrl;
      this.previewVisible = true;
    },

    /**
     * 处理业务变更
     * @param fileList 已经上传的文件列表
     * @private
     */
    _handleChange: function _handleChange(_ref) {
      var file = _ref.file;

      if (file.status === 'removed') {
        var index = this.fileList.findIndex(function (item) {
          return item.uid === file.uid;
        });

        if (index !== -1) {
          this.fileList.splice(index, 1);
        }
      }
    },

    /**
     * 取消预览
     * @private
     */
    _handleCancelPreview: function _handleCancelPreview() {
      this.previewVisible = false;
    },

    /**
     * 上传前的处理函数，处理支持的文件类型及大小
     * @param file
     * @returns {Promise<unknown>|boolean}
     * @private
     */
    _handleBeforeUpload: function _handleBeforeUpload(file) {
      var _this2 = this;

      var isJpgOrPng = file.type === 'image/jpeg' || file.type === 'image/png';

      if (!isJpgOrPng) {
        this.$message.error('只允许jpeg、png格式图片');
        return false;
      }

      var isLtSize = file.size < this.$props.maxStoreSize * 1024 * 1024;

      if (!isLtSize) {
        this.$message.error("\u56FE\u7247\u5927\u5C0F\u4E0D\u80FD\u8D85\u8FC7".concat(this.$props.maxStoreSize, "M"));
        return false;
      }

      if (this.$props.needSquare) {
        return new Promise(function (resolve, reject) {
          var reader = new FileReader();
          reader.readAsDataURL(file);

          reader.onload = function () {
            // 让页面中的img标签的src指向读取的路径
            var img = new Image();
            img.src = reader.result;

            if (img.complete) {
              // 如果存在浏览器缓存中
              _this2._getIsSquare(img, resolve, reject);
            } else {
              img.onload = function () {
                _this2._getIsSquare(img, resolve, reject);
              };
            }
          };
        });
      }

      return true; // return isJpgOrPng && isLtSize
    },

    /**
     * 判断是否是正方形的图
     * @param img
     * @param resolve
     * @param reject
     * @private
     */
    _getIsSquare: function _getIsSquare(img, resolve, reject) {
      var isSquare = img.width === img.height;

      if (!isSquare) {
        this.$message.error(this.$props.squareMsg);
        reject(new Error(this.$props.squareMsg));
      } else {
        resolve();
      }
    },

    /**
     * 自定义处理上传逻辑函数
     * @param file
     * @private
     */
    _handleCustomRequest: function () {
      var _handleCustomRequest2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(file) {
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.prev = 0;
                // console.log('~~~_handleCustomRequest~~~', file)
                this.loading = true;

                if (!this.$props.needSignature) {
                  _context.next = 7;
                  break;
                }

                _context.next = 5;
                return this._uploadBySignature(file.file);

              case 5:
                _context.next = 9;
                break;

              case 7:
                _context.next = 9;
                return this._upload(file.file);

              case 9:
                _context.next = 13;
                break;

              case 11:
                _context.prev = 11;
                _context.t0 = _context["catch"](0);

              case 13:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, this, [[0, 11]]);
      }));

      function _handleCustomRequest(_x) {
        return _handleCustomRequest2.apply(this, arguments);
      }

      return _handleCustomRequest;
    }(),

    /**
     * 普通上传上传
     * @param file
     * @private
     */
    _upload: function () {
      var _upload2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(file) {
        var fileSuffix, formData, data, key, instance, targetUrl;
        return _regeneratorRuntime.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                _context2.prev = 0;
                // 获取文件后缀名
                fileSuffix = this._getFileSuffix(file);
                formData = _extends({}, this.ossClient, {
                  name: file.name,
                  key: this.ossClient.dir + '/' + new Date().getTime() + '.' + fileSuffix
                });
                delete formData.dir;
                delete formData.endPoint;
                delete formData.bucket;
                data = new FormData();

                for (key in formData) {
                  data.append(key, formData[key]);
                }

                data.append('file', file);
                instance = axios.create();
                instance.defaults.headers = {
                  'Content-Type': 'multipart/form-data'
                };
                instance.defaults.baseURL = this.action;
                _context2.next = 14;
                return instance.request({
                  method: 'post',
                  data: data
                });

              case 14:
                targetUrl = "".concat(this.action, "/").concat(formData.key);

                this._uploadSuccess(file.name, targetUrl);

                _context2.next = 21;
                break;

              case 18:
                _context2.prev = 18;
                _context2.t0 = _context2["catch"](0);

                // 加密上传的事直接error.response.status
                this._uploadError(_context2.t0.response || _context2.t0);

              case 21:
              case "end":
                return _context2.stop();
            }
          }
        }, _callee2, this, [[0, 18]]);
      }));

      function _upload(_x2) {
        return _upload2.apply(this, arguments);
      }

      return _upload;
    }(),

    /**
     * 加密上传上传
     * @param file
     * @private
     */
    _uploadBySignature: function () {
      var _uploadBySignature2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3(file) {
        var fileName, fileSuffix, md5FileName, url, result, targetUrl;
        return _regeneratorRuntime.wrap(function _callee3$(_context3) {
          while (1) {
            switch (_context3.prev = _context3.next) {
              case 0:
                _context3.prev = 0;
                fileName = file.name; // 获取文件后缀名

                fileSuffix = this._getFileSuffix(file);
                md5FileName = md5(file.uid + '_' + fileName);
                url = "".concat(this.ossClient.fileFolder).concat(md5FileName, ".").concat(fileSuffix);
                _context3.next = 7;
                return this.ossClient.put(url, file);

              case 7:
                result = _context3.sent;
                targetUrl = this.ossClient.signatureUrl(result.name);

                this._uploadSuccess(fileName, targetUrl, result.name);

                _context3.next = 15;
                break;

              case 12:
                _context3.prev = 12;
                _context3.t0 = _context3["catch"](0);

                // 加密上传的事直接error.status
                this._uploadError(_context3.t0);

              case 15:
              case "end":
                return _context3.stop();
            }
          }
        }, _callee3, this, [[0, 12]]);
      }));

      function _uploadBySignature(_x3) {
        return _uploadBySignature2.apply(this, arguments);
      }

      return _uploadBySignature;
    }(),

    /**
     * 获取文件后缀
     * @param file
     * @returns {string|any}
     * @private
     */
    _getFileSuffix: function _getFileSuffix(file) {
      var name = file.name,
          type = file.type; // 获取文件后缀名获取后缀

      var fileSuffix = name.substring(name.lastIndexOf('.') + 1);

      if (FILE_SUFFIX_LIST.includes(fileSuffix)) {
        return fileSuffix;
      } // 根据文件类型来获取后缀


      fileSuffix = FILE_TYPE_SUFFIX_MAP[type];

      if (FILE_SUFFIX_LIST.includes(fileSuffix)) {
        return fileSuffix;
      } // 没有符合的默认使用png


      return 'png';
    },

    /**
     * 加密上传成功后处理
     * @param name
     * @param targetUrl
     * @param fileFolder 图片文件夹，加密上传有此参数
     * @private
     */
    _uploadSuccess: function _uploadSuccess(name, targetUrl, fileFolder) {
      this._addFileToFileList(name, targetUrl, fileFolder);

      this.$message.success('上传成功');
      this.loading = false;
    },

    /**
     * 上传失败后处理
     * @param error
     * @private
     */
    _uploadError: function _uploadError(error) {
      var status = error.status;
      this.loading = false;

      if (status === 403 || status === '403') {
        // 这里要考虑是不是真的是这样取错误码的
        this.$message.error('上传失败，请重试');

        this._resetOssClient();
      } else {
        this.$message.error('上传失败' + status);
      }
    },

    /**
     * 往文件列表里面添加文件
     * @param name 图片名称
     * @param targetUrl 图片url
     * @param fileFolder 图片文件夹，加密上传有此参数
     * @private
     */
    _addFileToFileList: function _addFileToFileList(name, targetUrl, fileFolder) {
      var fileItem = {
        uid: new Date().getTime(),
        status: 'done',
        name: name,
        url: targetUrl,
        // 缩略图
        thumbUrl: targetUrl,
        fileFolder: fileFolder
      };

      if (this.$props.maxCount === 1 && this.$props.listType === 'text') {
        this.fileList = [fileItem];
      } else {
        this.fileList.push(fileItem);
      }
    }
  },
  render: function render() {
    var h = arguments[0];
    var _this$$data = this.$data,
        fileList = _this$$data.fileList,
        disabled = _this$$data.disabled,
        loading = _this$$data.loading,
        previewVisible = _this$$data.previewVisible,
        previewImage = _this$$data.previewImage;
    var _this$$props = this.$props,
        maxCount = _this$$props.maxCount,
        listType = _this$$props.listType;
    return h("div", [h(AUpload, {
      attrs: {
        listType: listType,
        fileList: fileList,
        disabled: disabled,
        beforeUpload: this._handleBeforeUpload,
        customRequest: this._handleCustomRequest
      },
      on: {
        "preview": this._handlePreview,
        "change": this._handleChange
      }
    }, [fileList.length < maxCount ? h("div", [h(AIcon, {
      attrs: {
        type: loading ? 'loading' : 'plus'
      }
    }), h("div", {
      attrs: {
        className: "ant-upload-text"
      }
    }, [this.desc])]) : null]), h(AModal, {
      attrs: {
        visible: previewVisible,
        footer: null
      },
      on: {
        "cancel": this._handleCancelPreview
      }
    }, [h("img", {
      attrs: {
        alt: "example",
        src: previewImage
      },
      style: "width: 100%"
    })])]);
  }
};
